<?php

App::uses('BuzzSourceAppModel', 'BuzzSource.Model');

class WaiversApi extends BuzzSourceAppModel {

	/**
	 * Get vouchers for an activity type at a specific site
	 *
	 * @param string $email Customer email
	 * @param string $telephone Customer telephone number
	 * @return array
	 */
	public function getBooking($salesOrderId, $bookingDate = null) {

		$result = $this->find('all', array(
			'method' => 'GetBooking',
			'conditions' => array(
				'salesorderId' => $salesOrderId,
				'bookingdate' => $bookingDate
			)
		));

		return !empty($result['WaiversApi']['d']['Bookings']) ? $this->_processBookings($result['WaiversApi']['d']['Bookings']) : [];
	}

	public function signWaiver($model, $foreignId, $data) {

		$conditions = Hash::extract($data, 'Condition.{n}.title');

		$signedName = $data['Participant']['first_name'] . ' ' . $data['Participant']['last_name'];
		if (! empty($data['Participant']['adult_first_name'])) {
			$signedName = $data['Participant']['adult_first_name'] . ' ' . $data['Participant']['adult_last_name'];
		}

		$result = $this->find('all', array(
			'method' => 'SignWaiver',
			'conditions' => array(
				'dob' => $data['Participant']['date_of_birth'],
				'email' => $data['Participant']['email'],
				'forename' => $data['Participant']['first_name'],
				'surname' => $data['Participant']['last_name'],
				'signedname' => $signedName,
				'conditions' => json_encode($conditions)
			),
			'apiLog' => array(
				'model' => $model,
				'foreign_id' => $foreignId
			)
		));

		return !empty($result['WaiversApi']['d']) ? $result['WaiversApi']['d'] : false;
	}

	public function addWaiverPhoto($model, $foreignId, $data) {
		try {
			$result = $this->post('all', array(
				'method' => 'AddWaiverPhoto',
				'conditions' => array(
					'waiverId' => $data['waiverId'],
					'photo' => $data['photo']
				),
				'apiLog' => array(
					'model' => $model,
					'foreign_id' => $foreignId
				)
			));

		} catch (Exception $e) {
			CakeLog::write('debug', 'Photo Upload to API failed');
			CakeLog::write($e->getMessage());
		}
	}

	public function addWaiverSignature($model, $foreignId, $data) {
		try {
			$result = $this->post('all', array(
				'method' => 'AddWaiverSignature',
				'conditions' => array(
					'waiverId' => $data['waiverId'],
					'signature' => $data['signature']
				),
				'apiLog' => array(
					'model' => $model,
					'foreign_id' => $foreignId
				)
			));
		} catch (Exception $e) {
			CakeLog::write('debug', 'Photo Upload to API failed');
			CakeLog::write($e->getMessage());
		}
	}

	public function signChildWaiver($model, $foreignId, $data, $adultWaiverId = null) {
		$conditions = Hash::extract($data, 'Condition.{n}.title');

		$result = $this->find('all', array(
			'method' => 'SignChildWaiver',
			'conditions' => array(
				'parentId' => $data['Participant']['waiver_id'],
				'dob' => $data['Participant']['date_of_birth'],
				'email' => $data['Participant']['email'],
				'forename' => $data['Participant']['first_name'],
				'surname' => $data['Participant']['last_name'],
				'conditions' => json_encode($conditions)
			),
			'apiLog' => array(
				'model' => $model,
				'foreign_id' => $foreignId
			)
		));

		return !empty($result['WaiversApi']['d']) ? $result['WaiversApi']['d'] : false;
	}

	/**
	 * Process bookings data from the API
	 *
	 * @param array $data Response from API
	 * @return array
	 */
	protected function _processBookings($data) {
		$result = [];

		foreach ($data as $booking) {
			$result[] = [
				'contact_name' => $booking['ContactName'],
				'location' => $booking['Location'],
				'reference' => $booking['Reference'],
				'date' => $booking['BookingDate'],
				'check_in' => $booking['CheckInMins'],
				'description' => $booking['Description'],
				'participants' => $booking['Participants'],
				'message' => $booking['FailureDescription']
			];
		}

		return $result;
	}

}
